@@ -6,6 +6,7 @@ import org.gcube.data.analysis.dataminermanagercl.shared.data.OutputData;
 import org.gcube.data.analysis.dataminermanagercl.shared.data.computations.ComputationData;
 import org.gcube.data.analysis.dataminermanagercl.shared.data.computations.ComputationId;
 import org.gcube.data.analysis.dataminermanagercl.shared.process.OperatorsClassification;
+import org.gcube.data.analysis.dataminermanagercl.shared.service.ServiceInfo;
 import org.gcube.data.analysis.dataminermanagercl.shared.workspace.DataMinerWorkArea;
 import org.gcube.data.analysis.dataminermanagercl.shared.workspace.ItemDescription;
 import org.gcube.portlets.widgets.dataminermanagerwidget.client.common.EventBusProvider;
@@ -26,6 +27,8 @@ import org.gcube.portlets.widgets.dataminermanagerwidget.client.events.OutputDat
 import org.gcube.portlets.widgets.dataminermanagerwidget.client.events.RefreshDataMinerWorkAreaEvent;
 import org.gcube.portlets.widgets.dataminermanagerwidget.client.events.ResubmitComputationExecutionEvent;
 import org.gcube.portlets.widgets.dataminermanagerwidget.client.events.ResubmitComputationExecutionRequestEvent;
+import org.gcube.portlets.widgets.dataminermanagerwidget.client.events.ServiceInfoEvent;
+import org.gcube.portlets.widgets.dataminermanagerwidget.client.events.ServiceInfoRequestEvent;
 import org.gcube.portlets.widgets.dataminermanagerwidget.client.events.SessionExpiredEvent;
 import org.gcube.portlets.widgets.dataminermanagerwidget.client.events.StartComputationExecutionRequestEvent;
 import org.gcube.portlets.widgets.dataminermanagerwidget.client.events.TabularResourceInfoEvent;
@@ -253,6 +256,17 @@ public class DataMinerManagerController {
 
 				});
 
+		EventBusProvider.INSTANCE.addHandler(ServiceInfoRequestEvent.TYPE,
+				new ServiceInfoRequestEvent.ServiceInfoRequestEventHandler() {
+
+					@Override
+					public void onRequest(ServiceInfoRequestEvent event) {
+						Log.debug("Catch EnvironmentRequestEvent: " + event);
+						retrieveEnvironment(event);
+
+					}
+				});
+
 	}
 
 	private void restoreUISession() {
@@ -546,6 +560,33 @@ public class DataMinerManagerController {
 
 	}
 
+	private void retrieveEnvironment(final ServiceInfoRequestEvent event) {
+		DataMinerPortletServiceAsync.INSTANCE.getServiceInfo(new AsyncCallback<ServiceInfo>() {
+
+			@Override
+			public void onFailure(Throwable caught) {
+				if (caught instanceof SessionExpiredServiceException) {
+					UtilsGXT3.alert("Error", "Expired Session");
+					EventBusProvider.INSTANCE.fireEvent(new SessionExpiredEvent());
+				} else {
+					UtilsGXT3.alert("Error",
+							"Error retrieving DataMiner service info: " + caught.getLocalizedMessage());
+				}
+			}
+
+			@Override
+			public void onSuccess(ServiceInfo serviceInfo) {
+				Log.debug("DataMiner Service Info: " + serviceInfo);
+
+				ServiceInfoEvent serviceInfoEvent = new ServiceInfoEvent(serviceInfo);
+				EventBusProvider.INSTANCE.fireEvent(serviceInfoEvent);
+
+			}
+
+		});
+
+	}
+
 	private void fireDataMinerWorkAreaEventRetrieved(DataMinerWorkAreaRequestEvent event, DataMinerWorkArea result) {
 		dataMinerWorkArea = result;
 		DataMinerWorkAreaEvent dataMinerWorkAreaEvent = new DataMinerWorkAreaEvent(DataMinerWorkAreaEventType.OPEN,
